@@ -107,7 +107,35 @@ class LinguisticVariable(object):
 		
 
 	def __repr__(self):
-		return "L.V.: "+self._concept
+		if self._concept is None:
+			text = "N/A"
+		else:
+			text = self._concept
+		return "L.V.: "+text
+
+
+class AutoTriangle(LinguisticVariable):
+
+	def __init__(self, n_sets=3):
+
+		if n_sets<2:
+			raise Exception("Cannot create linguistic variable with less than 2 fuzzy sets.")
+
+		control_points = [x*1/(n_sets-1) for x in range(n_sets)]
+
+		FS_list = []
+
+		FS_list.append( Triangular_MF(0,0,control_points[1]) )
+
+		for n in range(1, n_sets-1):
+			FS_list.append( Triangular_MF( control_points[n-1], control_points[n], control_points[n+1] ) )
+
+		FS_list.append( Triangular_MF(control_points[-2], 1, 1) )
+
+		for i, fs in enumerate(FS_list):
+			fs._term = "case %d" % (i+1)
+
+		super().__init__(FS_list)
 
 
 class FuzzySystem(object):
